@@ -1,20 +1,19 @@
+use crate::color::TextFormat;
 use chrono;
 use std::fs::OpenOptions;
 use std::io::Write;
 use std::path::Path;
 
-pub fn get_logger() -> SimpleLogger {
-    SimpleLogger::new()
-}
-
 pub struct SimpleLogger {
     logfile: String,
+    text_formatter: TextFormat,
 }
 
 impl SimpleLogger {
     pub fn new() -> SimpleLogger {
         SimpleLogger {
             logfile: "/tmp/rustlog.txt".to_string(),
+            text_formatter: TextFormat::new(),
         }
     }
 
@@ -25,16 +24,17 @@ impl SimpleLogger {
                 .create(true)
                 .open(&self.logfile)
                 .unwrap();
-            file.write_all(b"<creat Rust SimpleLogger>\n")
+            file.write_all(b"<create Rust SimpleLogger>\n")
                 .expect("write to file error");
         }
     }
 
-    pub fn info(&self, msg: &str) {
+    pub fn _stream(&self, level: &str, msg: &str, color: &str) {
         let s = format!(
-            "[{}] [INFO]: {}",
+            "[{}] [{}]: {}",
             chrono::Local::now().format("%Y-%m-%d %H:%M:%S.%3f"),
-            msg
+            level,
+            self.text_formatter.colored(msg, color)
         );
         println!("{}", s);
         self.init();
@@ -48,4 +48,17 @@ impl SimpleLogger {
             eprintln!("Couldn't write to file: {}", e);
         }
     }
+    pub fn info(&self, msg: &str) {
+        self._stream("INFO", msg, "light_cyan");
+    }
+
+    pub fn warn(&self, msg: &str) {
+        self._stream("WARN", msg, "light_yellow");
+    }
+    pub fn warning(&self, msg: &str) {
+        self._stream("WARN", msg, "light_yellow");
+    }
+    pub fn error(&self, msg: &str) {
+        self._stream("ERROR", msg, "light_red");
+    }
 }
